@@ -27,6 +27,11 @@ int main(int argc, char **argv)
 {
   QApplication app( argc, argv );
 
+  /**
+   * enable high dpi support
+   */
+  app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
+
   Kdelibs4ConfigMigrator migrate(QLatin1String("kcharselect"));
   migrate.setConfigFiles(QStringList() << QLatin1String("kcharselectrc"));
   migrate.setUiFiles(QStringList() << QLatin1String("kcharselectui.rc"));
